==> knative-model-6.8.1-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1beta1/CloudEventOverridesFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CloudEventOverridesFluent<A extends CloudEventOverridesFluent<A>> extends BaseFluent<A>{
  public CloudEventOverridesFluent() {
  }
  public CloudEventOverridesFluent(CloudEventOverrides instance) {
    instance = (instance != null ? instance : new CloudEventOverrides());

    if (instance != null) {
      this.withExtensions(instance.getExtensions());
      this.withExtensions(instance.getExtensions());
    }
  }
  private Map<String,String> extensions;
  public A addToExtensions(String key,String value) {
    if(this.extensions == null && key != null && value != null) { this.extensions = new LinkedHashMap(); }
    if(key != null && value != null) {this.extensions.put(key, value);} return (A)this;
  }
  public A addToExtensions(Map<String,String> map) {
    if(this.extensions == null && map != null) { this.extensions = new LinkedHashMap(); }
    if(map != null) { this.extensions.putAll(map);} return (A)this;
  }
  public A removeFromExtensions(String key) {
    if(this.extensions == null) { return (A) this; }
    if(key != null && this.extensions != null) {this.extensions.remove(key);} return (A)this;
  }
  public A removeFromExtensions(Map<String,String> map) {
    if(this.extensions == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extensions != null){this.extensions.remove(key);}}} return (A)this;
  }
  public Map<String,String> getExtensions() {
    return this.extensions;
  }
  public <K,V>A withExtensions(Map<String,String> extensions) {
    if (extensions == null) { this.extensions =  null;} else {this.extensions = new LinkedHashMap(extensions);} return (A) this;
  }
  public boolean hasExtensions() {
    return this.extensions != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CloudEventOverridesFluent that = (CloudEventOverridesFluent) o;
    if (!java.util.Objects.equals(extensions, that.extensions)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(extensions,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (extensions != null && !extensions.isEmpty()) { sb.append("extensions:"); sb.append(extensions); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1beta1/CloudEventOverridesFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CloudEventOverridesFluent<A extends CloudEventOverridesFluent<A>> extends BaseFluent<A>{
  public CloudEventOverridesFluent() {
  }
  
  public CloudEventOverridesFluent(CloudEventOverrides instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> extensions;
  
  protected void copyInstance(CloudEventOverrides instance) {
    instance = (instance != null ? instance : new CloudEventOverrides());
  
    if (instance != null) {
        this.withExtensions(instance.getExtensions());
        this.withExtensions(instance.getExtensions());
      }
  }
  
  public A addToExtensions(String key,String value) {
    if(this.extensions == null && key != null && value != null) { this.extensions = new LinkedHashMap(); }
    if(key != null && value != null) {this.extensions.put(key, value);} return (A)this;
  }
  
  public A addToExtensions(Map<String,String> map) {
    if(this.extensions == null && map != null) { this.extensions = new LinkedHashMap(); }
    if(map != null) { this.extensions.putAll(map);} return (A)this;
  }
  
  public A removeFromExtensions(String key) {
    if(this.extensions == null) { return (A) this; }
    if(key != null && this.extensions != null) {this.extensions.remove(key);} return (A)this;
  }
  
  public A removeFromExtensions(Map<String,String> map) {
    if(this.extensions == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extensions != null){this.extensions.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getExtensions() {
    return this.extensions;
  }
  
  public <K,V>A withExtensions(Map<String,String> extensions) {
    if (extensions == null) { this.extensions =  null;} else {this.extensions = new LinkedHashMap(extensions);} return (A) this;
  }
  
  public boolean hasExtensions() {
    return this.extensions != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CloudEventOverridesFluent that = (CloudEventOverridesFluent) o;
    if (!java.util.Objects.equals(extensions, that.extensions)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(extensions,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (extensions != null && !extensions.isEmpty()) { sb.append("extensions:"); sb.append(extensions); }
    sb.append("}");
    return sb.toString();
  }
  

}
